quantizationtools.SilentQEvent
==============================

.. abjad-lineage:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent

.. autoclass:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.attachments
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.index
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.offset
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.storage_format
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__eq__
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__getstate__
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__lt__
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__ne__
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__repr__
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__setstate__

Bases
-----

- :py:class:`quantizationtools.QEvent <abjad.tools.quantizationtools.QEvent.QEvent.QEvent>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.attachments
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.storage_format
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SilentQEvent.SilentQEvent.SilentQEvent.__setstate__
   :noindex:
